multidim.models.CDER.evaluate — GDA Toolbox v1.0 Manual

# multidim.models.CDER.evaluate

`CDER.` `evaluate`(x)

  Evaluate all gaussians against a pointcloud

  Parameters: | x : `numpy.ndarray` An array, giving a pointcloud. Each row is a point.
  Returns: | functions : `numpy.ndarray` the integral of each gaussian over these points. labels : `numpy.ndarray` the labels of the gaussians, for reference.

#### Previous topic

multidim.models.CDER.build_gaussian

#### Next topic

multidim.models.CDER.fit